ACTION_ADVANCED_SETTINGS_CHANGED constant

String const ACTION_ADVANCED_SETTINGS_CHANGED

Broadcast Action: The user has switched on advanced settings in the settings app:

  • state - A boolean value indicating whether the settings is on or off.

This is a protected intent that can only be sent by the system.

@hide

Implementation

//
static const String ACTION_ADVANCED_SETTINGS_CHANGED =
    "android.intent.action.ADVANCED_SETTINGS";