ACTION_APP_ERROR constant

String const ACTION_APP_ERROR

Activity Action: The user pressed the "Report" button in the crash/ANR dialog. This intent is delivered to the package which installed the application, usually Google Play.

Input: No data is specified. The bug report is passed in using an {@link #EXTRA_BUG_REPORT} field.

Output: Nothing.

@see #EXTRA_BUG_REPORT

Implementation

static const String ACTION_APP_ERROR = "android.intent.action.APP_ERROR";