ACTION_BATTERY_OKAY constant

String const ACTION_BATTERY_OKAY

Broadcast Action: Indicates the battery is now okay after being low. This will be sent after {@link #ACTION_BATTERY_LOW} once the battery has gone back up to an okay state.

This is a protected intent that can only be sent by the system.

Implementation

static const String ACTION_BATTERY_OKAY =
    "android.intent.action.BATTERY_OKAY";