ACTION_CALL constant

String const ACTION_CALL

Activity Action: Perform a call to someone specified by the data.

Input: If nothing, an empty dialer is started; else {@link #getData} is URI of a phone number to be dialed or a tel: URI of an explicit phone number.

Output: nothing.

Note: there will be restrictions on which applications can initiate a call; most applications should use the {@link #ACTION_DIAL}.

Note: this Intent cannot be used to call emergency numbers. Applications can dial emergency numbers using {@link #ACTION_DIAL}, however.

Note: if you app targets {@link android.os.Build.VERSION_CODES#M M} and above and declares as using the {@link android.Manifest.permission#CALL_PHONE} permission which is not granted, then attempting to use this action will result in a {@link java.lang.SecurityException}.

Implementation

static const String ACTION_CALL = "android.intent.action.CALL";