ACTION_CANCEL_ENABLE_ROLLBACK constant

String const ACTION_CANCEL_ENABLE_ROLLBACK

Broadcast Action: Sent to the system rollback manager when the rollback for a certain package needs to be cancelled.

This intent is sent by PackageManagerService to notify RollbackManager that enabling a specific rollback has timed out.

@hide

Implementation

static const String ACTION_CANCEL_ENABLE_ROLLBACK =
    "android.intent.action.CANCEL_ENABLE_ROLLBACK";