ACTION_CARRIER_SETUP constant

String const ACTION_CARRIER_SETUP

Activity Action: Main entry point for carrier setup apps.

Carrier apps that provide an implementation for this action may be invoked to configure carrier service and typically require {@link android.telephony.TelephonyManager#hasCarrierPrivileges() carrier privileges} to fulfill their duties.

Implementation

static const String ACTION_CARRIER_SETUP =
    "android.intent.action.CARRIER_SETUP";