ACTION_CREATE_DOCUMENT constant
Activity Action: Allow the user to create a new document. When invoked, the system will display the various {@link DocumentsProvider} instances installed on the device, letting the user navigate through them. The returned document may be a newly created document with no content, or it may be an existing document with the requested MIME type.
Each document is represented as a {@code content://} URI backed by a {@link DocumentsProvider}, which can be opened as a stream with {@link ContentResolver#openFileDescriptor(Uri, String)}, or queried for {@link android.provider.DocumentsContract.Document} metadata.
Callers must indicate the concrete MIME type of the document being created by setting {@link #setType(String)}. This MIME type cannot be changed after the document is created.
Callers can provide an initial display name through {@link #EXTRA_TITLE}, but the user may change this value before creating the file.
Callers must include {@link #CATEGORY_OPENABLE} in the Intent to obtain URIs that can be opened with {@link ContentResolver#openFileDescriptor(Uri, String)}.
Callers can set a document URI through {@link DocumentsContract#EXTRA_INITIAL_URI} to indicate the initial location of documents navigator. System will do its best to launch the navigator in the specified document if it's a folder, or the folder that contains the specified document if not.
Output: The URI of the item that was created. This must be a {@code content://} URI so that any receiver can access it.
@see DocumentsContract @see #ACTION_OPEN_DOCUMENT @see #ACTION_OPEN_DOCUMENT_TREE @see #FLAG_GRANT_PERSISTABLE_URI_PERMISSION
Implementation
static const String ACTION_CREATE_DOCUMENT =
"android.intent.action.CREATE_DOCUMENT";