ACTION_DEVICE_CUSTOMIZATION_READY constant

String const ACTION_DEVICE_CUSTOMIZATION_READY

Broadcast Action: Indicates that a new device customization has been downloaded and applied (packages installed, runtime resource overlays enabled, xml files copied, ...), and that it is time for components that need to for example clear their caches to do so now.

@hide

Implementation

static const String ACTION_DEVICE_CUSTOMIZATION_READY =
    "android.intent.action.DEVICE_CUSTOMIZATION_READY";