ACTION_DEVICE_STORAGE_LOW constant

  1. @deprecated
String const ACTION_DEVICE_STORAGE_LOW

Broadcast Action: A sticky broadcast that indicates low storage space condition on the device

This is a protected intent that can only be sent by the system.

@deprecated if your app targets {@link android.os.Build.VERSION_CODES#O} or above, this broadcast will no longer be delivered to any {@link BroadcastReceiver} defined in your manifest. Instead, apps are strongly encouraged to use the improved {@link Context#getCacheDir()} behavior so the system can automatically free up storage when needed.

Implementation

@deprecated
static const String ACTION_DEVICE_STORAGE_LOW =
    "android.intent.action.DEVICE_STORAGE_LOW";