ACTION_DEVICE_STORAGE_NOT_FULL constant

  1. @deprecated
String const ACTION_DEVICE_STORAGE_NOT_FULL

Broadcast Action: Indicates storage space full condition on the device no longer exists.

This is a protected intent that can only be sent by the system.

@deprecated if your app targets {@link android.os.Build.VERSION_CODES#O} or above, this broadcast will no longer be delivered to any {@link BroadcastReceiver} defined in your manifest. Instead, apps are strongly encouraged to use the improved {@link Context#getCacheDir()} behavior so the system can automatically free up storage when needed. @hide

Implementation

@deprecated
static const String ACTION_DEVICE_STORAGE_NOT_FULL =
    "android.intent.action.DEVICE_STORAGE_NOT_FULL";