ACTION_DISTRACTING_PACKAGES_CHANGED constant

String const ACTION_DISTRACTING_PACKAGES_CHANGED

Broadcast Action: Distracting packages have been changed.

Includes the following extras:

  • {@link #EXTRA_CHANGED_PACKAGE_LIST} is the set of packages which have been changed.
  • {@link #EXTRA_CHANGED_UID_LIST} is the set of uids which have been changed.
  • {@link #EXTRA_DISTRACTION_RESTRICTIONS} the new restrictions set on these packages.

This is a protected intent that can only be sent by the system. It is only sent to registered receivers.

@see PackageManager#setDistractingPackageRestrictions(String[], int) @hide

Implementation

static const String ACTION_DISTRACTING_PACKAGES_CHANGED =
    "android.intent.action.DISTRACTING_PACKAGES_CHANGED";