ACTION_DOCK_ACTIVE constant

String const ACTION_DOCK_ACTIVE

Broadcast Action: Indicates the dock in active state while device is docked.

This is a protected intent that can only be sent by the system.

@hide

Implementation

static const String ACTION_DOCK_ACTIVE = "android.intent.action.DOCK_ACTIVE";