ACTION_DOCK_EVENT constant

String const ACTION_DOCK_EVENT

Broadcast Action: A sticky broadcast for changes in the physical docking state of the device.

The intent will have the following extra values:

  • {@link #EXTRA_DOCK_STATE} - the current dock state, indicating which dock the device is physically in.

This is intended for monitoring the current physical dock state. See {@link android.app.UiModeManager} for the normal API dealing with dock mode changes.

Implementation

static const String ACTION_DOCK_EVENT = "android.intent.action.DOCK_EVENT";