ACTION_DOCK_IDLE constant
String
const ACTION_DOCK_IDLE
Broadcast Action: Indicates the dock in idle state while device is docked.
This is a protected intent that can only be sent by the system.
@hide
Implementation
static const String ACTION_DOCK_IDLE = "android.intent.action.DOCK_IDLE";