ACTION_EXTERNAL_APPLICATIONS_AVAILABLE constant

String const ACTION_EXTERNAL_APPLICATIONS_AVAILABLE

Broadcast Action: Resources for a set of packages (which were previously unavailable) are currently available since the media on which they exist is available. The extra data {@link #EXTRA_CHANGED_PACKAGE_LIST} contains a list of packages whose availability changed. The extra data {@link #EXTRA_CHANGED_UID_LIST} contains a list of uids of packages whose availability changed. Note that the packages in this list do not receive this broadcast. The specified set of packages are now available on the system.

Includes the following extras:

  • {@link #EXTRA_CHANGED_PACKAGE_LIST} is the set of packages whose resources(were previously unavailable) are currently available. {@link #EXTRA_CHANGED_UID_LIST} is the set of uids of the packages whose resources(were previously unavailable) are currently available.

This is a protected intent that can only be sent by the system.

Implementation

static const String ACTION_EXTERNAL_APPLICATIONS_AVAILABLE =
    "android.intent.action.EXTERNAL_APPLICATIONS_AVAILABLE";