ACTION_GET_RESTRICTION_ENTRIES constant

String const ACTION_GET_RESTRICTION_ENTRIES

Broadcast to a specific application to query any supported restrictions to impose on restricted users. The broadcast intent contains an extra {@link #EXTRA_RESTRICTIONS_BUNDLE} with the currently persisted restrictions as a Bundle of key/value pairs. The value types can be Boolean, String or String[] depending on the restriction type.

The response should contain an extra {@link #EXTRA_RESTRICTIONS_LIST}, which is of type ArrayList<RestrictionEntry>. It can also contain an extra {@link #EXTRA_RESTRICTIONS_INTENT}, which is of type Intent. The activity specified by that intent will be launched for a result which must contain one of the extras {@link #EXTRA_RESTRICTIONS_LIST} or {@link #EXTRA_RESTRICTIONS_BUNDLE}. The keys and values of the returned restrictions will be persisted. @see RestrictionEntry

Implementation

static const String ACTION_GET_RESTRICTION_ENTRIES =
    "android.intent.action.GET_RESTRICTION_ENTRIES";