ACTION_IDLE_MAINTENANCE_END constant
Broadcast Action: A broadcast when idle maintenance should be stopped. This means that the user was not interacting with the device as a result of which a broadcast with action {@link #ACTION_IDLE_MAINTENANCE_START} was sent and now the user started interacting with the device. Typical use of the idle maintenance is to perform somehow expensive tasks that can be postponed at a moment when they will not degrade user experience.
In order to keep the device responsive in case of an unexpected user interaction, implementations of a maintenance task should be interruptible. Hence, on receiving a broadcast with this action, the maintenance task should be interrupted as soon as possible. In other words, you should not do the maintenance work in {@link BroadcastReceiver#onReceive(Context, Intent)}, rather stop the maintenance service that was started on receiving of {@link #ACTION_IDLE_MAINTENANCE_START}.Also you should release the wake lock you acquired when your maintenance service started.
This is a protected intent that can only be sent by the system.
@see #ACTION_IDLE_MAINTENANCE_START
@hide
Implementation
static const String ACTION_IDLE_MAINTENANCE_END =
"android.intent.action.ACTION_IDLE_MAINTENANCE_END";