ACTION_IDLE_MAINTENANCE_START constant

String const ACTION_IDLE_MAINTENANCE_START

Broadcast Action: A broadcast when idle maintenance can be started. This means that the user is not interacting with the device and is not expected to do so soon. Typical use of the idle maintenance is to perform somehow expensive tasks that can be postponed at a moment when they will not degrade user experience.

In order to keep the device responsive in case of an unexpected user interaction, implementations of a maintenance task should be interruptible. In such a scenario a broadcast with action {@link #ACTION_IDLE_MAINTENANCE_END} will be sent. In other words, you should not do the maintenance work in {@link BroadcastReceiver#onReceive(Context, Intent)}, rather start a maintenance service by {@link Context#startService(Intent)}. Also you should hold a wake lock while your maintenance service is running to prevent the device going to sleep.

This is a protected intent that can only be sent by the system.

@see #ACTION_IDLE_MAINTENANCE_END

@hide

Implementation

static const String ACTION_IDLE_MAINTENANCE_START =
    "android.intent.action.ACTION_IDLE_MAINTENANCE_START";