ACTION_INCIDENT_REPORT_READY constant
String
const ACTION_INCIDENT_REPORT_READY
An incident report has been taken, and the user has approved it for sharing.
This will be sent directly to the registered receiver, which must have both the DUMP and USAGE_STATS permissions.
After receiving this, the application should wait until a suitable time (e.g. network available), get the list of available reports with {@link IncidentManager#getIncidentReportList IncidentManager.getIncidentReportList(String)} and then when the reports have been successfully uploaded, call {@link IncidentManager#deleteIncidentReport IncidentManager.deleteIncidentReport(Uri)}.
@hide
Implementation
static const String ACTION_INCIDENT_REPORT_READY =
"android.intent.action.INCIDENT_REPORT_READY";