ACTION_MANAGED_PROFILE_AVAILABLE constant
String
const ACTION_MANAGED_PROFILE_AVAILABLE
Broadcast sent to the primary user when an associated managed profile has become available. Currently this includes when the user disables quiet mode for the profile. Carries an extra {@link #EXTRA_USER} that specifies the UserHandle of the profile. When quiet mode is changed, this broadcast will carry a boolean extra {@link #EXTRA_QUIET_MODE} indicating the new state of quiet mode. This is only sent to registered receivers, not manifest receivers.
Implementation
static const String ACTION_MANAGED_PROFILE_AVAILABLE =
"android.intent.action.MANAGED_PROFILE_AVAILABLE";