ACTION_MANAGED_PROFILE_REMOVED constant
String
const ACTION_MANAGED_PROFILE_REMOVED
Broadcast sent to the primary user when an associated managed profile is removed. Carries an extra {@link #EXTRA_USER} that specifies the UserHandle of the profile that was removed. Only applications (for example Launchers) that need to display merged content across both primary and managed profiles need to worry about this broadcast. This is only sent to registered receivers, not manifest receivers.
Implementation
static const String ACTION_MANAGED_PROFILE_REMOVED =
"android.intent.action.MANAGED_PROFILE_REMOVED";