ACTION_MEDIA_BAD_REMOVAL constant

String const ACTION_MEDIA_BAD_REMOVAL

Broadcast Action: External media was removed from SD card slot, but mount point was not unmounted. The path to the mount point for the removed media is contained in the Intent.mData field.

Implementation

static const String ACTION_MEDIA_BAD_REMOVAL =
    "android.intent.action.MEDIA_BAD_REMOVAL";