ACTION_MEDIA_NOFS constant

String const ACTION_MEDIA_NOFS

Broadcast Action: External media is present, but is using an incompatible fs (or is blank) The path to the mount point for the checking media is contained in the Intent.mData field.

Implementation

static const String ACTION_MEDIA_NOFS = "android.intent.action.MEDIA_NOFS";