ACTION_MEDIA_RESOURCE_GRANTED constant

String const ACTION_MEDIA_RESOURCE_GRANTED

Broadcast Action: Sent when media resource is granted.

{@link #EXTRA_PACKAGES} specifies the packages on the process holding the media resource granted.

This is a protected intent that can only be sent by the system.

This requires {@link android.Manifest.permission#RECEIVE_MEDIA_RESOURCE_USAGE} permission.

@hide

Implementation

static const String ACTION_MEDIA_RESOURCE_GRANTED =
    "android.intent.action.MEDIA_RESOURCE_GRANTED";