ACTION_MEDIA_UNMOUNTED constant

String const ACTION_MEDIA_UNMOUNTED

Broadcast Action: External media is present, but not mounted at its mount point. The path to the mount point for the unmounted media is contained in the Intent.mData field.

Implementation

static const String ACTION_MEDIA_UNMOUNTED =
    "android.intent.action.MEDIA_UNMOUNTED";