ACTION_MEDIA_UNSHARED constant

String const ACTION_MEDIA_UNSHARED

Broadcast Action: External media is no longer being shared via USB mass storage. The path to the mount point for the previously shared media is contained in the Intent.mData field.

@hide

Implementation

static const String ACTION_MEDIA_UNSHARED =
    "android.intent.action.MEDIA_UNSHARED";