ACTION_OVERLAY_CHANGED constant

String const ACTION_OVERLAY_CHANGED

Broadcast Action: An overlay package has changed. The data contains the name of the overlay package which has changed. This is broadcast on all changes to the OverlayInfo returned by {@link android.content.om.IOverlayManager#getOverlayInfo(String, int)}. The most common change is a state change that will change whether the overlay is enabled or not. @hide

Implementation

static const String ACTION_OVERLAY_CHANGED =
    "android.intent.action.OVERLAY_CHANGED";