ACTION_PACKAGE_DATA_CLEARED constant
String
const ACTION_PACKAGE_DATA_CLEARED
Broadcast Action: The user has cleared the data of a package. This should be preceded by {@link #ACTION_PACKAGE_RESTARTED}, after which all of its persistent data is erased and this broadcast sent. Note that the cleared package does not receive this broadcast. The data contains the name of the package.
- {@link #EXTRA_UID} containing the integer uid assigned to the package. If the package whose data was cleared is an uninstalled instant app, then the UID will be -1. The platform keeps some meta-data associated with instant apps after they are uninstalled.
- {@link #EXTRA_PACKAGE_NAME} containing the package name only if the cleared data was for an instant app.
This is a protected intent that can only be sent by the system.
Implementation
static const String ACTION_PACKAGE_DATA_CLEARED =
"android.intent.action.PACKAGE_DATA_CLEARED";