ACTION_PACKAGE_ENABLE_ROLLBACK constant

String const ACTION_PACKAGE_ENABLE_ROLLBACK

Broadcast Action: Sent to the system rollback manager when a package needs to have rollback enabled.

This is a protected intent that can only be sent by the system.

@hide This broadcast is used internally by the system.

Implementation

static const String ACTION_PACKAGE_ENABLE_ROLLBACK =
    "android.intent.action.PACKAGE_ENABLE_ROLLBACK";