ACTION_PACKAGE_FULLY_REMOVED constant

String const ACTION_PACKAGE_FULLY_REMOVED

Broadcast Action: An existing application package has been completely removed from the device. The data contains the name of the package. This is like {@link #ACTION_PACKAGE_REMOVED}, but only set when {@link #EXTRA_DATA_REMOVED} is true and {@link #EXTRA_REPLACING} is false of that broadcast.

  • {@link #EXTRA_UID} containing the integer uid previously assigned to the package.

This is a protected intent that can only be sent by the system.

Implementation

static const String ACTION_PACKAGE_FULLY_REMOVED =
    "android.intent.action.PACKAGE_FULLY_REMOVED";