ACTION_PACKAGE_INSTALL constant

  1. @deprecated
String const ACTION_PACKAGE_INSTALL

Broadcast Action: Trigger the download and eventual installation of a package.

Input: {@link #getData} is the URI of the package file to download.

This is a protected intent that can only be sent by the system.

@deprecated This constant has never been used.

Implementation

@deprecated
static const String ACTION_PACKAGE_INSTALL =
    "android.intent.action.PACKAGE_INSTALL";