ACTION_PACKAGE_REPLACED constant

String const ACTION_PACKAGE_REPLACED

Broadcast Action: A new version of an application package has been installed, replacing an existing version that was previously installed. The data contains the name of the package.

May include the following extras:

  • {@link #EXTRA_UID} containing the integer uid assigned to the new package.

This is a protected intent that can only be sent by the system.

Implementation

static const String ACTION_PACKAGE_REPLACED =
    "android.intent.action.PACKAGE_REPLACED";