ACTION_PASTE constant

String const ACTION_PASTE

Activity Action: Create a new item in the given container, initializing it from the current contents of the clipboard.

Input: {@link #getData} is URI of the directory (vnd.android.cursor.dir/*) in which to place the data.

Output: URI of the new data that was created.

Implementation

static const String ACTION_PASTE = "android.intent.action.PASTE";