ACTION_QUERY_PACKAGE_RESTART constant

String const ACTION_QUERY_PACKAGE_RESTART

@hide Broadcast Action: Ask system services if there is any reason to restart the given package. The data contains the name of the package.

  • {@link #EXTRA_UID} containing the integer uid assigned to the package.
  • {@link #EXTRA_PACKAGES} String array of all packages to check.

This is a protected intent that can only be sent by the system.

Implementation

static const String ACTION_QUERY_PACKAGE_RESTART =
    "android.intent.action.QUERY_PACKAGE_RESTART";