ACTION_RESOLVE_INSTANT_APP_PACKAGE constant

String const ACTION_RESOLVE_INSTANT_APP_PACKAGE

Service Action: Resolve instant application.

The system will have a persistent connection to this service. This is a protected intent that can only be sent by the system.

@hide

Implementation

static const String ACTION_RESOLVE_INSTANT_APP_PACKAGE =
    "android.intent.action.RESOLVE_INSTANT_APP_PACKAGE";