ACTION_SEND_MULTIPLE constant
Activity Action: Deliver multiple data to someone else.
Like {@link #ACTION_SEND}, except the data is multiple.
Input: {@link #getType} is the MIME type of the data being sent. get*ArrayListExtra can have either a {@link #EXTRA_TEXT} or {@link #EXTRA_STREAM} field, containing the data to be sent. If using {@link #EXTRA_TEXT}, you can also optionally supply {@link #EXTRA_HTML_TEXT} for clients to retrieve your text with HTML formatting.
Multiple types are supported, and receivers should handle mixed types whenever possible. The right way for the receiver to check them is to use the content resolver on each URI. The intent sender should try to put the most concrete mime type in the intent type, but it can fall back to {@literal
e.g. if you are sending image/jpg and image/jpg, the intent's type can be image/jpg, but if you are sending image/jpg and image/png, then the intent's type should be image/*.
As of {@link android.os.Build.VERSION_CODES#JELLY_BEAN}, the data being sent can be supplied through {@link #setClipData(ClipData)}. This allows you to use {@link #FLAG_GRANT_READ_URI_PERMISSION} when sharing content: URIs and other advanced features of {@link ClipData}. If using this approach, you still must supply the same data through the {@link #EXTRA_TEXT} or {@link #EXTRA_STREAM} fields described below for compatibility with old applications. If you don't set a ClipData, it will be copied there for you when calling {@link Context#startActivity(Intent)}.
Starting from {@link android.os.Build.VERSION_CODES#O}, if {@link #CATEGORY_TYPED_OPENABLE} is passed, then the Uris passed in either {@link #EXTRA_STREAM} or via {@link #setClipData(ClipData)} may be openable only as asset typed files using {@link ContentResolver#openTypedAssetFileDescriptor(Uri, String, Bundle)}.
Optional standard extras, which may be interpreted by some recipients as appropriate, are: {@link #EXTRA_EMAIL}, {@link #EXTRA_CC}, {@link #EXTRA_BCC}, {@link #EXTRA_SUBJECT}.
Output: nothing.
Implementation
static const String ACTION_SEND_MULTIPLE =
"android.intent.action.SEND_MULTIPLE";