ACTION_SHOW_APP_INFO constant

String const ACTION_SHOW_APP_INFO

Activity Action: Launch an activity showing the app information. For applications which install other applications (such as app stores), it is recommended to handle this action for providing the app information to the user.

Input: {@link #EXTRA_PACKAGE_NAME} specifies the package whose information needs to be displayed.

Output: Nothing.

Implementation

static const String ACTION_SHOW_APP_INFO =
    "android.intent.action.SHOW_APP_INFO";