ACTION_SHOW_SUSPENDED_APP_DETAILS constant

String const ACTION_SHOW_SUSPENDED_APP_DETAILS

Activity Action: Started to show more details about why an application was suspended.

Whenever the system detects an activity launch for a suspended app, this action can be used to show more details about the reason for suspension.

Apps holding {@link android.Manifest.permission#SUSPEND_APPS} must declare an activity handling this intent and protect it with {@link android.Manifest.permission#SEND_SHOW_SUSPENDED_APP_DETAILS}.

Includes an extra {@link #EXTRA_PACKAGE_NAME} which is the name of the suspended package.

This is a protected intent that can only be sent by the system.

@see PackageManager#setPackagesSuspended(String[], boolean, PersistableBundle, PersistableBundle, String) @see PackageManager#isPackageSuspended() @see #ACTION_PACKAGES_SUSPENDED

@hide

Implementation

static const String ACTION_SHOW_SUSPENDED_APP_DETAILS =
    "android.intent.action.SHOW_SUSPENDED_APP_DETAILS";