ACTION_UID_REMOVED constant

String const ACTION_UID_REMOVED

Broadcast Action: A user ID has been removed from the system. The user ID number is stored in the extra data under {@link #EXTRA_UID}.

This is a protected intent that can only be sent by the system.

Implementation

static const String ACTION_UID_REMOVED = "android.intent.action.UID_REMOVED";