ACTION_USER_PRESENT constant

String const ACTION_USER_PRESENT

Broadcast Action: Sent when the user is present after device wakes up (e.g when the keyguard is gone).

This is a protected intent that can only be sent by the system.

Implementation

static const String ACTION_USER_PRESENT =
    "android.intent.action.USER_PRESENT";