ACTION_USER_SWITCHED constant

String const ACTION_USER_SWITCHED

Broadcast sent to the system when the user switches. Carries an extra EXTRA_USER_HANDLE that has the userHandle of the user to become the current one. This is only sent to registered receivers, not manifest receivers. It is sent to all running users. You must hold {@link android.Manifest.permission#MANAGE_USERS} to receive this broadcast. @hide

Implementation

static const String ACTION_USER_SWITCHED =
    "android.intent.action.USER_SWITCHED";