ACTION_VIEW constant
String
const ACTION_VIEW
Activity Action: Display the data to the user. This is the most common action performed on data -- it is the generic action you can use on a piece of data to get the most reasonable thing to occur. For example, when used on a contacts entry it will view the entry; when used on a mailto: URI it will bring up a compose window filled with the information supplied by the URI; when used with a tel: URI it will invoke the dialer.
Input: {@link #getData} is URI from which to retrieve data.
Output: nothing.
Implementation
static const String ACTION_VIEW = 'android.intent.action.VIEW';