CATEGORY_APP_CONTACTS constant
String
const CATEGORY_APP_CONTACTS
Used with {@link #ACTION_MAIN} to launch the contacts application. The activity should be able to view and manipulate address book entries.
NOTE: This should not be used as the primary key of an Intent, since it will not result in the app launching with the correct action and category. Instead, use this with {@link #makeMainSelectorActivity(String, String)} to generate a main Intent with this category in the selector.
Implementation
static const String CATEGORY_APP_CONTACTS =
"android.intent.category.APP_CONTACTS";