CATEGORY_DEFAULT constant

String const CATEGORY_DEFAULT

Set if the activity should be an option for the default action (center press) to perform on a piece of data. Setting this will hide from the user any activities without it set when performing an action on some data. Note that this is normally -not- set in the Intent when initiating an action -- it is for use in intent filters specified in packages.

Implementation

static const String CATEGORY_DEFAULT = "android.intent.category.DEFAULT";