CATEGORY_INFO constant

String const CATEGORY_INFO

Provides information about the package it is in; typically used if a package does not contain a {@link #CATEGORY_LAUNCHER} to provide a front-door to the user without having to be shown in the all apps list.

Implementation

static const String CATEGORY_INFO = "android.intent.category.INFO";