CATEGORY_TAB constant
String
const CATEGORY_TAB
Intended to be used as a tab inside of a containing TabActivity.
Implementation
static const String CATEGORY_TAB = "android.intent.category.TAB";
Intended to be used as a tab inside of a containing TabActivity.
static const String CATEGORY_TAB = "android.intent.category.TAB";