EXTRA_ALARM_COUNT constant

String const EXTRA_ALARM_COUNT

Used as an int extra field in {@link android.app.AlarmManager} intents to tell the application being invoked how many pending alarms are being delievered with the intent. For one-shot alarms this will always be 1. For recurring alarms, this might be greater than 1 if the device was asleep or powered off at the time an earlier alarm would have been delivered.

Implementation

static const String EXTRA_ALARM_COUNT = "android.intent.extra.ALARM_COUNT";