EXTRA_ALLOW_REPLACE constant

  1. @deprecated
String const EXTRA_ALLOW_REPLACE

Used as a boolean extra field with {@link #ACTION_INSTALL_PACKAGE} to install a package. Tells the installer UI to skip the confirmation with the user if the .apk is replacing an existing one. @deprecated As of {@link android.os.Build.VERSION_CODES#JELLY_BEAN}, Android will no longer show an interstitial message about updating existing applications so this is no longer needed.

Implementation

@deprecated
static const String EXTRA_ALLOW_REPLACE =
    "android.intent.extra.ALLOW_REPLACE";