EXTRA_CHOOSER_REFINEMENT_INTENT_SENDER constant
String
const EXTRA_CHOOSER_REFINEMENT_INTENT_SENDER
An {@link IntentSender} for an Activity that will be invoked when the user makes a selection from the chooser activity presented by {@link #ACTION_CHOOSER}.
An app preparing an action for another app to complete may wish to allow the user to disambiguate between several options for completing the action based on the chosen target or otherwise refine the action before it is invoked.
When sent, this IntentSender may be filled in with the following extras:
- {@link #EXTRA_INTENT} The first intent that matched the user's chosen target
- {@link #EXTRA_ALTERNATE_INTENTS} Any additional intents that also matched the user's chosen target beyond the first
- {@link #EXTRA_RESULT_RECEIVER} A {@link ResultReceiver} that the refinement activity should fill in and send once the disambiguation is complete
Implementation
static const String EXTRA_CHOOSER_REFINEMENT_INTENT_SENDER =
"android.intent.extra.CHOOSER_REFINEMENT_INTENT_SENDER";