EXTRA_CHOOSER_TARGETS constant

String const EXTRA_CHOOSER_TARGETS

A {@link android.service.chooser.ChooserTarget ChooserTarget[]} for {@link #ACTION_CHOOSER} describing additional high-priority deep-link targets for the chooser to present to the user.

Targets provided in this way will be presented inline with all other targets provided by services from other apps. They will be prioritized before other service targets, but after those targets provided by sources that the user has manually pinned to the front.

@see #ACTION_CHOOSER

Implementation

static const String EXTRA_CHOOSER_TARGETS =
    "android.intent.extra.CHOOSER_TARGETS";