EXTRA_CHOSEN_COMPONENT_INTENT_SENDER constant

String const EXTRA_CHOSEN_COMPONENT_INTENT_SENDER

An {@link IntentSender} that will be notified if a user successfully chooses a target component to handle an action in an {@link #ACTION_CHOOSER} activity. The IntentSender will have the extra {@link #EXTRA_CHOSEN_COMPONENT} appended to it containing the {@link ComponentName} of the chosen component.

In some situations this callback may never come, for example if the user abandons the chooser, switches to another task or any number of other reasons. Apps should not be written assuming that this callback will always occur.

Implementation

static const String EXTRA_CHOSEN_COMPONENT_INTENT_SENDER =
    "android.intent.extra.CHOSEN_COMPONENT_INTENT_SENDER";