EXTRA_CLIENT_LABEL constant

String const EXTRA_CLIENT_LABEL

@hide Magic extra system code can use when binding, to give a label for who it is that has bound to a service. This is an integer giving a framework string resource that can be displayed to the user.

Implementation

static const String EXTRA_CLIENT_LABEL = "android.intent.extra.client_label";