EXTRA_CONTENT_ANNOTATIONS constant

String const EXTRA_CONTENT_ANNOTATIONS

An {@code ArrayList} of {@code String} annotations describing content for {@link #ACTION_CHOOSER}.

If {@link #EXTRA_CONTENT_ANNOTATIONS} is present in an intent used to start a {@link #ACTION_CHOOSER} activity, the first three annotations will be used to rank apps.

Annotations should describe the major components or topics of the content. It is up to apps initiating {@link #ACTION_CHOOSER} to learn and add annotations. Annotations should be learned in advance, e.g., when creating or saving content, to avoid increasing latency to start {@link #ACTION_CHOOSER}. Names of customized annotations should not contain the colon character. Performance on customized annotations can suffer, if they are rarely used for {@link #ACTION_CHOOSER} in the past 14 days. Therefore, it is recommended to use the following annotations when applicable.

  • "product" represents that the topic of the content is mainly about products, e.g., health & beauty, and office supplies.
  • "emotion" represents that the topic of the content is mainly about emotions, e.g., happy, and sad.
  • "person" represents that the topic of the content is mainly about persons, e.g., face, finger, standing, and walking.
  • "child" represents that the topic of the content is mainly about children, e.g., child, and baby.
  • "selfie" represents that the topic of the content is mainly about selfies.
  • "crowd" represents that the topic of the content is mainly about crowds.
  • "party" represents that the topic of the content is mainly about parties.
  • "animal" represent that the topic of the content is mainly about animals.
  • "plant" represents that the topic of the content is mainly about plants, e.g., flowers.
  • "vacation" represents that the topic of the content is mainly about vacations.
  • "fashion" represents that the topic of the content is mainly about fashion, e.g. sunglasses, jewelry, handbags and clothing.
  • "material" represents that the topic of the content is mainly about materials, e.g., paper, and silk.
  • "vehicle" represents that the topic of the content is mainly about vehicles, like cars, and boats.
  • "document" represents that the topic of the content is mainly about documents, e.g. posters.
  • "design" represents that the topic of the content is mainly about design, e.g. arts and designs of houses.
  • "holiday" represents that the topic of the content is mainly about holidays, e.g., Christmas and Thanksgiving.

Implementation

static const String EXTRA_CONTENT_ANNOTATIONS =
    "android.intent.extra.CONTENT_ANNOTATIONS";