EXTRA_DATA_OPERATOR_ALPHA_LONG constant

  1. @deprecated
String const EXTRA_DATA_OPERATOR_ALPHA_LONG

A string extra used with {@link #ACTION_SERVICE_STATE} which represents the current registered data operator name in long alphanumeric format. {@code null} if the operator name is not known or unregistered. @hide @removed @deprecated Use {@link android.provider.Telephony.ServiceStateTable#DATA_OPERATOR_ALPHA_LONG}.

Implementation

@deprecated
static const String EXTRA_DATA_OPERATOR_ALPHA_LONG =
    "data-operator-alpha-long";