EXTRA_EXCLUDE_COMPONENTS constant
String
const EXTRA_EXCLUDE_COMPONENTS
A {@link ComponentName ComponentName[]} describing components that should be filtered out and omitted from a list of components presented to the user.
When used with {@link #ACTION_CHOOSER}, the chooser will omit any of the components
in this array if it otherwise would have shown them. Useful for omitting specific targets
from your own package or other apps from your organization if the idea of sending to those
targets would be redundant with other app functionality. Filtered components will not
be able to present targets from an associated ChooserTargetService.
Implementation
static const String EXTRA_EXCLUDE_COMPONENTS =
"android.intent.extra.EXCLUDE_COMPONENTS";