EXTRA_INITIAL_INTENTS constant

String const EXTRA_INITIAL_INTENTS

A Parcelable[] of {@link Intent} or {@link android.content.pm.LabeledIntent} objects as set with {@link #putExtra(String, Parcelable[])} of additional activities to place a the front of the list of choices, when shown to the user with a {@link #ACTION_CHOOSER}.

Implementation

static const String EXTRA_INITIAL_INTENTS =
    "android.intent.extra.INITIAL_INTENTS";