EXTRA_LOCAL_ONLY constant
String
const EXTRA_LOCAL_ONLY
Extra used to indicate that an intent should only return data that is on the local device. This is a boolean extra; the default is false. If true, an implementation should only allow the user to select data that is already on the device, not requiring it be downloaded from a remote service when opened.
@see #ACTION_GET_CONTENT @see #ACTION_OPEN_DOCUMENT @see #ACTION_OPEN_DOCUMENT_TREE @see #ACTION_CREATE_DOCUMENT
Implementation
static const String EXTRA_LOCAL_ONLY = "android.intent.extra.LOCAL_ONLY";