EXTRA_OPERATOR_ALPHA_LONG constant
A string extra used with {@link #ACTION_SERVICE_STATE} which represents the current registered voice operator name in long alphanumeric format. {@code null} if the operator name is not known or unregistered. @hide @removed @deprecated Use {@link android.provider.Telephony.ServiceStateTable#VOICE_OPERATOR_ALPHA_LONG}.
Implementation
@deprecated
static const String EXTRA_OPERATOR_ALPHA_LONG = "operator-alpha-long";