EXTRA_QUICK_VIEW_ADVANCED constant

  1. @deprecated
String const EXTRA_QUICK_VIEW_ADVANCED

Tells the quick viewer to show additional UI actions suitable for the passed Uris, such as opening in other apps, sharing, opening, editing, printing, deleting, casting, etc.

The value is boolean. By default false. @see #ACTION_QUICK_VIEW @removed

Implementation

@deprecated
static const String EXTRA_QUICK_VIEW_ADVANCED =
    "android.intent.extra.QUICK_VIEW_ADVANCED";