EXTRA_REFERRER constant
String
const EXTRA_REFERRER
This extra can be used with any Intent used to launch an activity, supplying information about who is launching that activity. This field contains a {@link android.net.Uri} object, typically an http: or https: URI of the web site that the referral came from; it can also use the {@link #URI_ANDROID_APP_SCHEME android-app:} scheme to identify a native application that it came from.
To retrieve this value in a client, use {@link android.app.Activity#getReferrer} instead of directly retrieving the extra. It is also valid for applications to instead supply {@link #EXTRA_REFERRER_NAME} for cases where they can only create a string, not a Uri; the field here, if supplied, will always take precedence, however.
@see #EXTRA_REFERRER_NAME
Implementation
static const String EXTRA_REFERRER = "android.intent.extra.REFERRER";