EXTRA_RESULT_RECEIVER constant

String const EXTRA_RESULT_RECEIVER

A {@link ResultReceiver} used to return data back to the sender.

Used to complete an app-specific {@link #EXTRA_CHOOSER_REFINEMENT_INTENT_SENDER refinement} for {@link #ACTION_CHOOSER}.

If {@link #EXTRA_CHOOSER_REFINEMENT_INTENT_SENDER} is present in the intent used to start a {@link #ACTION_CHOOSER} activity this extra will be {@link #fillIn(Intent, int) filled in} to that {@link IntentSender} and sent when the user selects a target component from the chooser. It is up to the recipient to send a result to this ResultReceiver to signal that disambiguation is complete and that the chooser should invoke the user's choice.

The disambiguator should provide a Bundle to the ResultReceiver with an intent assigned to the key {@link #EXTRA_INTENT}. This supplied intent will be used by the chooser to match and fill in the const Intent or ChooserTarget before starting it. The supplied intent must {@link #filterEquals(Intent) match} one of the intents from {@link #EXTRA_INTENT} or {@link #EXTRA_ALTERNATE_INTENTS} passed to {@link #EXTRA_CHOOSER_REFINEMENT_INTENT_SENDER} to be accepted.

The result code passed to the ResultReceiver should be {@link android.app.Activity#RESULT_OK} if the refinement succeeded and the supplied intent's target in the chooser should be started, or {@link android.app.Activity#RESULT_CANCELED} if the chooser should finish without starting a target.

Implementation

static const String EXTRA_RESULT_RECEIVER =
    "android.intent.extra.RESULT_RECEIVER";