EXTRA_USER_ID constant
String
const EXTRA_USER_ID
An int representing the user id to be used.
@hide
Implementation
static const String EXTRA_USER_ID = "android.intent.extra.USER_ID";
An int representing the user id to be used.
@hide
static const String EXTRA_USER_ID = "android.intent.extra.USER_ID";