FLAG_ACTIVITY_BROUGHT_TO_FRONT constant

int const FLAG_ACTIVITY_BROUGHT_TO_FRONT

This flag is not normally set by application code, but set for you by the system as described in the {@link android.R.styleable#AndroidManifestActivity_launchMode launchMode} documentation for the singleTask mode.

Implementation

static const int FLAG_ACTIVITY_BROUGHT_TO_FRONT = 0x00400000;