FLAG_ACTIVITY_FORWARD_RESULT constant

int const FLAG_ACTIVITY_FORWARD_RESULT

If set and this intent is being used to launch a new activity from an existing one, then the reply target of the existing activity will be transferred to the new activity. This way, the new activity can call {@link android.app.Activity#setResult} and have that result sent back to the reply target of the original activity.

Implementation

static const int FLAG_ACTIVITY_FORWARD_RESULT = 0x02000000;