FLAG_ACTIVITY_LAUNCHED_FROM_HISTORY constant

int const FLAG_ACTIVITY_LAUNCHED_FROM_HISTORY

This flag is not normally set by application code, but set for you by the system if this activity is being launched from history (longpress home key).

Implementation

static const int FLAG_ACTIVITY_LAUNCHED_FROM_HISTORY = 0x00100000;