FLAG_ACTIVITY_NO_HISTORY constant
int
const FLAG_ACTIVITY_NO_HISTORY
If set, the new activity is not kept in the history stack. As soon as the user navigates away from it, the activity is finished. This may also be set with the {@link android.R.styleable#AndroidManifestActivity_noHistory noHistory} attribute.
If set, {@link android.app.Activity#onActivityResult onActivityResult()} is never invoked when the current activity starts a new activity which sets a result and finishes.
Implementation
static const int FLAG_ACTIVITY_NO_HISTORY = 0x40000000;