FLAG_ACTIVITY_NO_USER_ACTION constant

int const FLAG_ACTIVITY_NO_USER_ACTION

If set, this flag will prevent the normal {@link android.app.Activity#onUserLeaveHint} callback from occurring on the current frontmost activity before it is paused as the newly-started activity is brought to the front.

Typically, an activity can rely on that callback to indicate that an explicit user action has caused their activity to be moved out of the foreground. The callback marks an appropriate point in the activity's lifecycle for it to dismiss any notifications that it intends to display "until the user has seen them," such as a blinking LED.

If an activity is ever started via any non-user-driven events such as phone-call receipt or an alarm handler, this flag should be passed to {@link Context#startActivity Context.startActivity}, ensuring that the pausing activity does not think the user has acknowledged its notification.

Implementation

static const int FLAG_ACTIVITY_NO_USER_ACTION = 0x00040000;