FLAG_ACTIVITY_PREVIOUS_IS_TOP constant

int const FLAG_ACTIVITY_PREVIOUS_IS_TOP

If set and this intent is being used to launch a new activity from an existing one, the current activity will not be counted as the top activity for deciding whether the new intent should be delivered to the top instead of starting a new one. The previous activity will be used as the top, with the assumption being that the current activity will finish itself immediately.

Implementation

static const int FLAG_ACTIVITY_PREVIOUS_IS_TOP = 0x01000000;