FLAG_ACTIVITY_REQUIRE_NON_BROWSER constant

int const FLAG_ACTIVITY_REQUIRE_NON_BROWSER

If set in an intent passed to {@link Context#startActivity Context.startActivity()}, this flag will only launch the intent if it resolves to a result that is not a browser. If no such result exists, an {@link ActivityNotFoundException} will be thrown.

Implementation

static const int FLAG_ACTIVITY_REQUIRE_NON_BROWSER = 0x00000400;