FLAG_ACTIVITY_TASK_ON_HOME constant
int
const FLAG_ACTIVITY_TASK_ON_HOME
If set in an Intent passed to {@link Context#startActivity Context.startActivity()}, this flag will cause a newly launching task to be placed on top of the current home activity task (if there is one). That is, pressing back from the task will always return the user to home even if that was not the last activity they saw. This can only be used in conjunction with {@link #FLAG_ACTIVITY_NEW_TASK}.
Implementation
static const int FLAG_ACTIVITY_TASK_ON_HOME = 0X00004000;