FLAG_DEBUG_LOG_RESOLUTION constant

int const FLAG_DEBUG_LOG_RESOLUTION

A flag you can enable for debugging: when set, log messages will be printed during the resolution of this intent to show you what has been found to create the const resolved list.

Implementation

static const int FLAG_DEBUG_LOG_RESOLUTION = 0x00000008;