FLAG_EXCLUDE_STOPPED_PACKAGES constant

int const FLAG_EXCLUDE_STOPPED_PACKAGES

If set, this intent will not match any components in packages that are currently stopped. If this is not set, then the default behavior is to include such applications in the result.

Implementation

static const int FLAG_EXCLUDE_STOPPED_PACKAGES = 0x00000010;