FLAG_GRANT_PERSISTABLE_URI_PERMISSION constant

int const FLAG_GRANT_PERSISTABLE_URI_PERMISSION

When combined with {@link #FLAG_GRANT_READ_URI_PERMISSION} and/or {@link #FLAG_GRANT_WRITE_URI_PERMISSION}, the URI permission grant can be persisted across device reboots until explicitly revoked with {@link Context#revokeUriPermission(Uri, int)}. This flag only offers the grant for possible persisting; the receiving application must call {@link ContentResolver#takePersistableUriPermission(Uri, int)} to actually persist.

@see ContentResolver#takePersistableUriPermission(Uri, int) @see ContentResolver#releasePersistableUriPermission(Uri, int) @see ContentResolver#getPersistedUriPermissions() @see ContentResolver#getOutgoingPersistedUriPermissions()

Implementation

static const int FLAG_GRANT_PERSISTABLE_URI_PERMISSION = 0x00000040;