FLAG_GRANT_PREFIX_URI_PERMISSION constant
int
const FLAG_GRANT_PREFIX_URI_PERMISSION
When combined with {@link #FLAG_GRANT_READ_URI_PERMISSION} and/or {@link #FLAG_GRANT_WRITE_URI_PERMISSION}, the URI permission grant applies to any URI that is a prefix match against the original granted URI. (Without this flag, the URI must match exactly for access to be granted.) Another URI is considered a prefix match only when scheme, authority, and all path segments defined by the prefix are an exact match.
Implementation
static const int FLAG_GRANT_PREFIX_URI_PERMISSION = 0x00000080;