FLAG_RECEIVER_INCLUDE_BACKGROUND constant

int const FLAG_RECEIVER_INCLUDE_BACKGROUND

If set, the broadcast will always go to manifest receivers in background (cached or not running) apps, regardless of whether that would be done by default. By default they will only receive broadcasts if the broadcast has specified an explicit component or package name.

NOTE: dumpstate uses this flag numerically, so when its value is changed the broadcast code there must also be changed to match.

@hide

Implementation

static const int FLAG_RECEIVER_INCLUDE_BACKGROUND = 0x01000000;