FLAG_RECEIVER_NO_ABORT constant

int const FLAG_RECEIVER_NO_ABORT

If this is an ordered broadcast, don't allow receivers to abort the broadcast. They can still propagate results through to later receivers, but they can not prevent later receivers from seeing the broadcast.

Implementation

static const int FLAG_RECEIVER_NO_ABORT = 0x08000000;