FLAG_RECEIVER_REGISTERED_ONLY_BEFORE_BOOT constant
int
const FLAG_RECEIVER_REGISTERED_ONLY_BEFORE_BOOT
If set, when sending a broadcast before the system has fully booted up (which is even before {@link #ACTION_LOCKED_BOOT_COMPLETED} has been sent)" only registered receivers will be called -- no BroadcastReceiver components will be launched. Sticky intent state will be recorded properly even if no receivers wind up being called. If {@link #FLAG_RECEIVER_REGISTERED_ONLY} is specified in the broadcast intent, this flag is unnecessary.
This flag is only for use by system services (even services from mainline modules) as a convenience to avoid having to implement a more complex mechanism around detection of boot completion.
This is useful to system server mainline modules
@hide
Implementation
static const int FLAG_RECEIVER_REGISTERED_ONLY_BEFORE_BOOT = 0x04000000;