FLAG_RECEIVER_VISIBLE_TO_INSTANT_APPS constant

int const FLAG_RECEIVER_VISIBLE_TO_INSTANT_APPS

If set, the broadcast will be visible to receivers in Instant Apps. By default Instant Apps will not receive broadcasts.

This flag has no effect when used by an Instant App.

Implementation

static const int FLAG_RECEIVER_VISIBLE_TO_INSTANT_APPS = 0x00200000;