METADATA_DOCK_HOME constant

String const METADATA_DOCK_HOME

Boolean that can be supplied as meta-data with a dock activity, to indicate that the dock should take over the home key when it is active.

Implementation

static const String METADATA_DOCK_HOME = "android.dock_home";