PackageItemInfo class

Implementers

Properties

getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
icon int
getter/setter pair
labelRes int
getter/setter pair
getter/setter pair
name String?
getter/setter pair
nonLocalizedLabel String?
getter/setter pair
packageName String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getApplicationInfo() ApplicationInfo?
loadBanner(PackageManager pm) Uint8List?
loadIcon(PackageManager pm) Uint8List
loadLabel(PackageManager pm) String
loadUnbadgedIcon(PackageManager pm) Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

forceSafeLabels() → void