EXTRA_MAX_CHANNEL_COUNT constant
String
const EXTRA_MAX_CHANNEL_COUNT
Extra used in {@link #ACTION_HDMI_AUDIO_PLUG} to define the maximum number of channels supported by the HDMI device. The corresponding integer value is only available when the device is plugged in (as expressed by {@link #EXTRA_AUDIO_PLUG_STATE}).
Implementation
static const String EXTRA_MAX_CHANNEL_COUNT =
"android.media.extra.MAX_CHANNEL_COUNT";