FLAG_FROM_KEY constant
int
const FLAG_FROM_KEY
Adjusting the volume due to a hardware key press. @hide
Implementation
static const int FLAG_FROM_KEY = 1 << 12;
Adjusting the volume due to a hardware key press. @hide
static const int FLAG_FROM_KEY = 1 << 12;