FLAG_PLAY_SOUND constant

int const FLAG_PLAY_SOUND

Whether to play a sound when changing the volume.

If this is given to {@link #adjustVolume(int, int)} or {@link #adjustSuggestedStreamVolume(int, int, int)}, it may be ignored in some cases (for example, the decided stream type is not {@link AudioManager#STREAM_RING}, or the volume is being adjusted downward).

@see #adjustStreamVolume(int, int, int) @see #adjustVolume(int, int) @see #setStreamVolume(int, int, int)

Implementation

static const int FLAG_PLAY_SOUND = 1 << 2;