STREAM_BLUETOOTH_SCO constant
int
const STREAM_BLUETOOTH_SCO
@hide The audio stream for phone calls when connected to bluetooth */
Implementation
static const int STREAM_BLUETOOTH_SCO = 6;
@hide The audio stream for phone calls when connected to bluetooth */
static const int STREAM_BLUETOOTH_SCO = 6;