STREAM_MUTE_CHANGED_ACTION constant

String const STREAM_MUTE_CHANGED_ACTION

@hide Broadcast intent when a stream mute state changes. Includes the stream that changed and the new mute state

@see #EXTRA_VOLUME_STREAM_TYPE @see #EXTRA_STREAM_VOLUME_MUTED

Implementation

static const String STREAM_MUTE_CHANGED_ACTION =
    "android.media.STREAM_MUTE_CHANGED_ACTION";