STREAM_TTS constant
int
const STREAM_TTS
@hide The audio stream for text to speech (TTS) */
Implementation
static const int STREAM_TTS = 9;
@hide The audio stream for text to speech (TTS) */
static const int STREAM_TTS = 9;