VIBRATE_SETTING_OFF constant

int const VIBRATE_SETTING_OFF

Vibrate setting that suggests to never vibrate.

@see #setVibrateSetting(int, int) @see #getVibrateSetting(int) @deprecated Applications should maintain their own vibrate policy based on current ringer mode that can be queried via {@link #getRingerMode()}.

Implementation

static const int VIBRATE_SETTING_OFF = 0;