adjustStreamVolume method
Adjusts the volume of a particular stream by one step in a direction.
This method should only be used by applications that replace the platform-wide management of audio settings or the main telephony application.
@param streamType The stream type to adjust. One of {@link #STREAM_VOICE_CALL}, {@link #STREAM_SYSTEM}, {@link #STREAM_RING}, {@link #STREAM_MUSIC} or {@link #STREAM_ALARM} @param direction The direction to adjust the volume. One of {@link #ADJUST_LOWER}, {@link #ADJUST_RAISE}, or {@link #ADJUST_SAME}. @param flags One or more flags. @see #adjustVolume(int, int) @see #setStreamVolume(int, int, int)
Implementation
Future<void> adjustStreamVolume(
int streamType, int direction, int flags) async {}