adjustSuggestedStreamVolume method

Future adjustSuggestedStreamVolume(
  1. int direction,
  2. int suggestedStreamType,
  3. int flags
)

Adjusts the volume of the most relevant stream, or the given fallback stream.

This method should only be used by applications that replace the platform-wide management of audio settings or the main telephony application.

@param direction The direction to adjust the volume. One of {@link #ADJUST_LOWER}, {@link #ADJUST_RAISE}, or {@link #ADJUST_SAME}. @param suggestedStreamType The stream type that will be used if there isn't a relevant stream. {@link #USE_DEFAULT_STREAM_TYPE} is valid here. @param flags One or more flags. @see #adjustVolume(int, int) @see #adjustStreamVolume(int, int, int) @see #setStreamVolume(int, int, int)

Implementation

Future adjustSuggestedStreamVolume(
    int direction, int suggestedStreamType, int flags) async {}