clear method
void
clear()
Removes all elements from the mapping of this Bundle.
Implementation
void clear() {
// unparcel();
_map.clear();
}
Removes all elements from the mapping of this Bundle.
void clear() {
// unparcel();
_map.clear();
}