putDouble method

void putDouble(
  1. String key,
  2. double value
)

Inserts a double value into the mapping of this Bundle, replacing any existing value for the given key.

@param key a String, or null @param value a double

Implementation

void putDouble(String key, double value) {
  // unparcel();
  _map[key] = value;
}