ACTION_ADD_ACCOUNT constant
String
const ACTION_ADD_ACCOUNT
Activity Action: Show add account screen for creating a new account.
In some cases, a matching Activity may not exist, so ensure you safeguard against this.
The account types available to add may be restricted by adding an {@link #EXTRA_AUTHORITIES} extra to the Intent with one or more syncable content provider's authorities. Only account types which can sync with that content provider will be offered to the user.
Account types can also be filtered by adding an {@link #EXTRA_ACCOUNT_TYPES} extra to the Intent with one or more account types.
Input: Nothing.
Output: Nothing.
Implementation
static const String ACTION_ADD_ACCOUNT =
"android.settings.ADD_ACCOUNT_SETTINGS";