ACTION_IGNORE_BATTERY_OPTIMIZATION_SETTINGS constant

String const ACTION_IGNORE_BATTERY_OPTIMIZATION_SETTINGS

Activity Action: Show screen for controlling which apps can ignore battery optimizations.

Input: Nothing.

Output: Nothing.

You can use {@link android.os.PowerManager#isIgnoringBatteryOptimizations PowerManager.isIgnoringBatteryOptimizations()} to determine if an application is already ignoring optimizations. You can use {@link #ACTION_REQUEST_IGNORE_BATTERY_OPTIMIZATIONS} to ask the user to put you on this list.

Implementation

static const String ACTION_IGNORE_BATTERY_OPTIMIZATION_SETTINGS =
    "android.settings.IGNORE_BATTERY_OPTIMIZATION_SETTINGS";