ACTION_LOCATION_SOURCE_SETTINGS constant

String const ACTION_LOCATION_SOURCE_SETTINGS

Activity Action: Show settings to allow configuration of current location sources.

In some cases, a matching Activity may not exist, so ensure you safeguard against this.

Input: Nothing.

Output: Nothing.

Implementation

static const String ACTION_LOCATION_SOURCE_SETTINGS =
    "android.settings.LOCATION_SOURCE_SETTINGS";