ACTION_MONITORING_CERT_INFO constant

String const ACTION_MONITORING_CERT_INFO

Activity Action: Show dialog explaining that an installed CA cert may enable monitoring of encrypted network traffic.

In some cases, a matching Activity may not exist, so ensure you safeguard against this. Add {@link #EXTRA_NUMBER_OF_CERTIFICATES} extra to indicate the number of certificates.

Input: Nothing.

Output: Nothing. @hide

Implementation

static const String ACTION_MONITORING_CERT_INFO =
    "com.android.settings.MONITORING_CERT_INFO";