ACTION_SHOW_ADMIN_SUPPORT_DETAILS constant

String const ACTION_SHOW_ADMIN_SUPPORT_DETAILS

@hide */ static const String EXTRA_APP_UID = "app_uid"; Activity Action: Show a dialog with disabled by policy message.

If an user action is disabled by policy, this dialog can be triggered to let the user know about this.

Input: Nothing.

Output: Nothing.

@hide

Implementation

/// Activity Action: Show a dialog with disabled by policy message.
/// <p> If an user action is disabled by policy, this dialog can be triggered to let
/// the user know about this.
/// <p>
/// Input: Nothing.
/// <p>
/// Output: Nothing.
///
/// @hide

static const String ACTION_SHOW_ADMIN_SUPPORT_DETAILS =
    "android.settings.SHOW_ADMIN_SUPPORT_DETAILS";