ACTION_SYNC_SETTINGS constant

String const ACTION_SYNC_SETTINGS

Activity Action: Show settings to allow configuration of sync settings.

In some cases, a matching Activity may not exist, so ensure you safeguard against this.

The account types available to add via the add account button may be restricted by adding an {@link #EXTRA_AUTHORITIES} extra to this Intent with one or more syncable content provider's authorities. Only account types which can sync with that content provider will be offered to the user.

Input: Nothing.

Output: Nothing.

Implementation

static const String ACTION_SYNC_SETTINGS = "android.settings.SYNC_SETTINGS";