ACTION_TETHER_PROVISIONING constant

String const ACTION_TETHER_PROVISIONING

Activity Action: Show tether provisioning activity.

In some cases, a matching Activity may not exist, so ensure you safeguard against this.

Input: {@link ConnectivityManager#EXTRA_TETHER_TYPE} should be included to specify which type of tethering should be checked. {@link ConnectivityManager#EXTRA_PROVISION_CALLBACK} should contain a {@link ResultReceiver} which will be called back with a tether result code.

Output: The result of the provisioning check. {@link ConnectivityManager#TETHER_ERROR_NO_ERROR} if successful, {@link ConnectivityManager#TETHER_ERROR_PROVISION_FAILED} for failure.

@hide

Implementation

static const String ACTION_TETHER_PROVISIONING =
    "android.settings.TETHER_PROVISIONING_UI";