ACTION_USER_DICTIONARY_SETTINGS constant

String const ACTION_USER_DICTIONARY_SETTINGS

Activity Action: Show settings to manage the user input dictionary.

Starting with {@link android.os.Build.VERSION_CODES#KITKAT}, it is guaranteed there will always be an appropriate implementation for this Intent action. In prior releases of the platform this was optional, so ensure you safeguard against it.

Input: Nothing.

Output: Nothing.

Implementation

static const String ACTION_USER_DICTIONARY_SETTINGS =
    "android.settings.USER_DICTIONARY_SETTINGS";