ACTION_VOICE_CONTROL_AIRPLANE_MODE property

String ACTION_VOICE_CONTROL_AIRPLANE_MODE
final

Activity Action: Modify Airplane mode settings using a voice command.

In some cases, a matching Activity may not exist, so ensure you safeguard against this.

This intent MUST be started using {@link android.service.voice.VoiceInteractionSession#startVoiceActivity startVoiceActivity}.

Note: The activity implementing this intent MUST verify that {@link android.app.Activity#isVoiceInteraction isVoiceInteraction} returns true before modifying the setting.

Input: To tell which state airplane mode should be set to, add the {@link #EXTRA_AIRPLANE_MODE_ENABLED} extra to this Intent with the state specified. If the extra is not included, no changes will be made.

Output: Nothing.

Implementation

static final String ACTION_VOICE_CONTROL_AIRPLANE_MODE =
    "android.settings.VOICE_CONTROL_AIRPLANE_MODE";