ACTION_WIRELESS_SETTINGS constant

String const ACTION_WIRELESS_SETTINGS

Activity Action: Show settings to allow configuration of wireless controls such as Wi-Fi, Bluetooth and Mobile networks.

In some cases, a matching Activity may not exist, so ensure you safeguard against this.

Input: Nothing.

Output: Nothing.

Implementation

static const String ACTION_WIRELESS_SETTINGS =
    "android.settings.WIRELESS_SETTINGS";