onForegroundMethodCall static method
Implementation
static Future<void> onForegroundMethodCall(MethodCall call) async {
log("onForegoundMethodCall ${call.method}");
switch (call.method) {
case "dispatchResultCallback":
/**
* this method called from background isolote in native code
* so we need to use isolate to send the message to main isolate.
*/
// final Map args = call.arguments;
// final sendPort =
// IsolateNameServer.lookupPortByName(WORKMANAGER_EVENT_PORT_NAME);
// args["method"] = call.method;
// sendPort.send(args);
break;
}
}