ACTION_AIRPLANE_MODE_CHANGED constant
String
const ACTION_AIRPLANE_MODE_CHANGED
Broadcast Action: The user has switched the phone into or out of Airplane Mode. One or more radios have been turned off or on. The intent will have the following extra value:
- state - A boolean value indicating whether Airplane Mode is on. If true, then cell radio and possibly other radios such as bluetooth or WiFi may have also been turned off
This is a protected intent that can only be sent by the system.
Implementation
static const String ACTION_AIRPLANE_MODE_CHANGED =
"android.intent.action.AIRPLANE_MODE";