ACTION_APPLICATION_PREFERENCES constant
String
const ACTION_APPLICATION_PREFERENCES
An activity that provides a user interface for adjusting application preferences. Optional but recommended settings for all applications which have settings.
Implementation
static const String ACTION_APPLICATION_PREFERENCES =
"android.intent.action.APPLICATION_PREFERENCES";