ACTION_BATTERY_CHANGED constant
String
const ACTION_BATTERY_CHANGED
Broadcast Action: This is a sticky broadcast containing the charging state, level, and other information about the battery. See {@link android.os.BatteryManager} for documentation on the contents of the Intent.
You cannot receive this through components declared in manifests, only by explicitly registering for it with {@link Context#registerReceiver(BroadcastReceiver, IntentFilter) Context.registerReceiver()}. See {@link #ACTION_BATTERY_LOW}, {@link #ACTION_BATTERY_OKAY}, {@link #ACTION_POWER_CONNECTED}, and {@link #ACTION_POWER_DISCONNECTED} for distinct battery-related broadcasts that are sent and can be received through manifest receivers.
This is a protected intent that can only be sent by the system.
Implementation
static const String ACTION_BATTERY_CHANGED =
"android.intent.action.BATTERY_CHANGED";