ACTION_DYNAMIC_SENSOR_CHANGED constant
String
const ACTION_DYNAMIC_SENSOR_CHANGED
Broadcast Action: List of dynamic sensor is changed due to new sensor being connected or exisiting sensor being disconnected.
This is a protected intent that can only be sent by the system.
{@hide}
Implementation
static const String ACTION_DYNAMIC_SENSOR_CHANGED =
"android.intent.action.DYNAMIC_SENSOR_CHANGED";