ACTION_INSERT_OR_EDIT constant
String
const ACTION_INSERT_OR_EDIT
Activity Action: Pick an existing item, or insert a new item, and then edit it.
Input: {@link #getType} is the desired MIME type of the item to create or edit. The extras can contain type specific data to pass through to the editing/creating activity.
Output: The URI of the item that was picked. This must be a content: URI so that any receiver can access it.
Implementation
static const String ACTION_INSERT_OR_EDIT =
'android.intent.action.INSERT_OR_EDIT';