ACTION_LOAD_DATA constant
String
const ACTION_LOAD_DATA
Used by {@link services.core.java.com.android.server.pm.DataLoaderManagerService} for querying Data Loader Service providers. Data loader service providers register this intent filter in their manifests, so that they can be looked up and bound to by {@code DataLoaderManagerService}.
This is a protected intent that can only be sent by the system.
Data loader service providers must be privileged apps. See {@link com.android.server.pm.PackageManagerShellCommandDataLoader} as an example of such data loader service provider.
@hide
Implementation
static const String ACTION_LOAD_DATA = "android.intent.action.LOAD_DATA";