ACTION_MANAGE_NETWORK_USAGE constant
String
const ACTION_MANAGE_NETWORK_USAGE
Activity Action: Show settings for managing network data usage of a specific application. Applications should define an activity that offers options to control data usage.
Implementation
static const String ACTION_MANAGE_NETWORK_USAGE =
"android.intent.action.MANAGE_NETWORK_USAGE";