ACTION_MANAGE_PACKAGE_STORAGE constant
String
const ACTION_MANAGE_PACKAGE_STORAGE
Broadcast Action: Indicates low memory condition notification acknowledged by user and package management should be started. This is triggered by the user from the ACTION_DEVICE_STORAGE_LOW notification.
Implementation
static const String ACTION_MANAGE_PACKAGE_STORAGE =
"android.intent.action.MANAGE_PACKAGE_STORAGE";