ACTION_MEDIA_SCANNER_SCAN_FILE constant
Broadcast Action: Request the media scanner to scan a file and add it to the media database.
The path to the file is contained in {@link Intent#getData()}.
@deprecated Callers should migrate to inserting items directly into {@link MediaStore}, where they will be automatically scanned after each mutation.
Implementation
@deprecated
static const String ACTION_MEDIA_SCANNER_SCAN_FILE =
"android.intent.action.MEDIA_SCANNER_SCAN_FILE";