ACTION_MY_PACKAGE_SUSPENDED constant
String
const ACTION_MY_PACKAGE_SUSPENDED
Broadcast Action: Sent to a package that has been suspended by the system. This is sent whenever a package is put into a suspended state or any of its app extras change while in the suspended state.
Optionally includes the following extras:
- {@link #EXTRA_SUSPENDED_PACKAGE_EXTRAS} which is a {@link Bundle} which will contain useful information for the app being suspended.
This is a protected intent that can only be sent by the system. This will be delivered to {@link BroadcastReceiver} components declared in the manifest.
@see #ACTION_MY_PACKAGE_UNSUSPENDED @see #EXTRA_SUSPENDED_PACKAGE_EXTRAS @see PackageManager#isPackageSuspended() @see PackageManager#getSuspendedPackageAppExtras()
Implementation
static const String ACTION_MY_PACKAGE_SUSPENDED =
"android.intent.action.MY_PACKAGE_SUSPENDED";