ACTION_PACKAGES_UNSUSPENDED constant
String
const ACTION_PACKAGES_UNSUSPENDED
Broadcast Action: Packages have been unsuspended.
Includes the following extras:
- {@link #EXTRA_CHANGED_PACKAGE_LIST} is the set of packages which have been unsuspended
- {@link #EXTRA_CHANGED_UID_LIST} is the set of uids which have been unsuspended
This is a protected intent that can only be sent by the system. It is only sent to registered receivers.
Implementation
static const String ACTION_PACKAGES_UNSUSPENDED =
"android.intent.action.PACKAGES_UNSUSPENDED";