ACTION_PACKAGE_NEEDS_INTEGRITY_VERIFICATION constant
String
const ACTION_PACKAGE_NEEDS_INTEGRITY_VERIFICATION
Broadcast Action: Sent to the integrity component when a package needs to be verified. The data contains the package URI along with other relevant information.
This is a protected intent that can only be sent by the system.
@hide
Implementation
static const String ACTION_PACKAGE_NEEDS_INTEGRITY_VERIFICATION =
"android.intent.action.PACKAGE_NEEDS_INTEGRITY_VERIFICATION";