ACTION_PACKAGE_NEEDS_VERIFICATION constant
String
const ACTION_PACKAGE_NEEDS_VERIFICATION
Broadcast Action: Sent to the system package verifier when a package needs to be verified. The data contains the package URI.
This is a protected intent that can only be sent by the system.
Implementation
static const String ACTION_PACKAGE_NEEDS_VERIFICATION =
"android.intent.action.PACKAGE_NEEDS_VERIFICATION";