ACTION_PACKAGE_REMOVED constant
String
const ACTION_PACKAGE_REMOVED
Broadcast Action: An existing application package has been removed from the device. The data contains the name of the package. The package that is being removed does not receive this Intent.
- {@link #EXTRA_UID} containing the integer uid previously assigned to the package.
- {@link #EXTRA_DATA_REMOVED} is set to true if the entire application -- data and code -- is being removed.
- {@link #EXTRA_REPLACING} is set to true if this will be followed by an {@link #ACTION_PACKAGE_ADDED} broadcast for the same package.
This is a protected intent that can only be sent by the system.
Implementation
static const String ACTION_PACKAGE_REMOVED =
"android.intent.action.PACKAGE_REMOVED";