ACTION_REVIEW_PERMISSIONS constant
Activity action: Launch UI to review permissions for an app. The system uses this intent if permission review for apps not supporting the new runtime permissions model is enabled. In this mode a permission review is required before any of the app components can run.
Input: {@link #EXTRA_PACKAGE_NAME} specifies the package whose permissions will be reviewed (mandatory).
Input: {@link #EXTRA_INTENT} specifies a pending intent to be fired after the permission review (optional).
Input: {@link #EXTRA_REMOTE_CALLBACK} specifies a callback to be invoked after the permission review (optional).
Input: {@link #EXTRA_RESULT_NEEDED} specifies whether the intent passed via {@link #EXTRA_INTENT} needs a result (optional).
Output: Nothing.
@see #EXTRA_PACKAGE_NAME @see #EXTRA_INTENT @see #EXTRA_REMOTE_CALLBACK @see #EXTRA_RESULT_NEEDED
@hide
Implementation
static const String ACTION_REVIEW_PERMISSIONS =
"android.intent.action.REVIEW_PERMISSIONS";