ACTION_REVIEW_PERMISSION_USAGE constant
Activity action: Launch UI to review app uses of permissions.
Input: {@link #EXTRA_PERMISSION_NAME} specifies the permission name that will be displayed by the launched UI. Do not pass both this and {@link #EXTRA_PERMISSION_GROUP_NAME} .
Input: {@link #EXTRA_PERMISSION_GROUP_NAME} specifies the permission group name that will be displayed by the launched UI. Do not pass both this and {@link #EXTRA_PERMISSION_NAME}.
Input: {@link #EXTRA_DURATION_MILLIS} specifies the minimum number of milliseconds of recent activity to show (optional). Must be non-negative.
Output: Nothing.
This requires {@link android.Manifest.permission#GRANT_RUNTIME_PERMISSIONS} permission.
@see #EXTRA_PERMISSION_NAME @see #EXTRA_PERMISSION_GROUP_NAME @see #EXTRA_DURATION_MILLIS
@hide
Implementation
static const String ACTION_REVIEW_PERMISSION_USAGE =
"android.intent.action.REVIEW_PERMISSION_USAGE";