ACTION_THERMAL_EVENT constant
String
const ACTION_THERMAL_EVENT
Broadcast action: reports when a new thermal event has been reached. When the device is reaching its maximum temperatue, the thermal level reported {@hide}
Implementation
static const String ACTION_THERMAL_EVENT =
"android.intent.action.THERMAL_EVENT";