ACTION_TIME_TICK constant
String
const ACTION_TIME_TICK
Broadcast Action: The current time has changed. Sent every minute. You cannot receive this through components declared in manifests, only by explicitly registering for it with {@link Context#registerReceiver(BroadcastReceiver, IntentFilter) Context.registerReceiver()}.
This is a protected intent that can only be sent by the system.
Implementation
static const String ACTION_TIME_TICK = "android.intent.action.TIME_TICK";