ACTION_UNINSTALL_PACKAGE constant
Activity Action: Launch application uninstaller.
Input: The data must be a package: URI whose scheme specific part is the package name of the current installed package to be uninstalled. You can optionally supply {@link #EXTRA_RETURN_RESULT}.
Output: If {@link #EXTRA_RETURN_RESULT}, returns whether the install succeeded.
Requires {@link android.Manifest.permission#REQUEST_DELETE_PACKAGES} since {@link Build.VERSION_CODES#P}.
@deprecated Use {@link android.content.pm.PackageInstaller#uninstall(String, IntentSender)} instead
Implementation
@deprecated
static const String ACTION_UNINSTALL_PACKAGE =
"android.intent.action.UNINSTALL_PACKAGE";