ACTION_USER_BACKGROUND constant
String
const ACTION_USER_BACKGROUND
Sent when a user switch is happening, causing the process's user to be sent to the background. This is only sent to receivers registered through {@link Context#registerReceiver(BroadcastReceiver, IntentFilter) Context.registerReceiver}. It is sent to the user that is going to the background. This is sent as a foreground broadcast, since it is part of a visible user interaction; be as quick as possible when handling it.
Implementation
static const String ACTION_USER_BACKGROUND =
"android.intent.action.USER_BACKGROUND";