ACTION_VIEW_LOCUS constant
String
const ACTION_VIEW_LOCUS
Activity Action: Display an activity state associated with an unique {@link LocusId}.
For example, a chat app could use the context to resume a conversation between 2 users.
Input: {@link #EXTRA_LOCUS_ID} specifies the unique identifier of the locus in the app domain. Should be stable across reboots and backup / restore.
Output: nothing.
Implementation
static const String ACTION_VIEW_LOCUS = "android.intent.action.VIEW_LOCUS";