CATEGORY_CAR_LAUNCHER constant
String
const CATEGORY_CAR_LAUNCHER
Indicates the preferred entry-point activity when an application is launched from a Car launcher. If not present, Car launcher can optionally use {@link #CATEGORY_LAUNCHER} as a fallback, or exclude the application entirely. @hide
Implementation
static const String CATEGORY_CAR_LAUNCHER =
"android.intent.category.CAR_LAUNCHER";