CATEGORY_HOME_MAIN constant
String
const CATEGORY_HOME_MAIN
This is the home activity that is displayed when the device is finished setting up and ready for use. @hide
Implementation
static const String CATEGORY_HOME_MAIN = "android.intent.category.HOME_MAIN";