CATEGORY_SETUP_WIZARD constant
String
const CATEGORY_SETUP_WIZARD
This is the setup wizard activity, that is the first activity that is displayed when the user sets up the device for the first time. @hide
Implementation
static const String CATEGORY_SETUP_WIZARD =
"android.intent.category.SETUP_WIZARD";