EXTRA_AUTO_LAUNCH_SINGLE_CHOICE constant
String
const EXTRA_AUTO_LAUNCH_SINGLE_CHOICE
Used as a boolean extra field in {@link #ACTION_CHOOSER} intents to specify whether to show the chooser or not when there is only one application available to choose from.
Implementation
static const String EXTRA_AUTO_LAUNCH_SINGLE_CHOICE =
"android.intent.extra.AUTO_LAUNCH_SINGLE_CHOICE";