EXTRA_CHANGED_COMPONENT_NAME_LIST constant
String
const EXTRA_CHANGED_COMPONENT_NAME_LIST
This field is part of {@link android.content.Intent#ACTION_PACKAGE_CHANGED}, and contains a string array of all of the components that have changed. If the state of the overall package has changed, then it will contain an entry with the package name itself.
Implementation
static const String EXTRA_CHANGED_COMPONENT_NAME_LIST =
"android.intent.extra.changed_component_name_list";