EXTRA_CLIENT_INTENT constant
String
const EXTRA_CLIENT_INTENT
@hide Magic extra system code can use when binding, to give a PendingIntent object that can be launched for the user to disable the system's use of this service.
Implementation
static const String EXTRA_CLIENT_INTENT =
"android.intent.extra.client_intent";