EXTRA_DATA_OPERATOR_ALPHA_SHORT constant
A string extra used with {@link #ACTION_SERVICE_STATE} which represents the current registered data operator name in short alphanumeric format. {@code null} if the operator name is not known or unregistered. @hide @removed @deprecated Use {@link android.provider.Telephony.ServiceStateTable#DATA_OPERATOR_ALPHA_SHORT}.
Implementation
@deprecated
static const String EXTRA_DATA_OPERATOR_ALPHA_SHORT =
"data-operator-alpha-short";