EXTRA_INSTANT_APP_EXTRAS constant
String
const EXTRA_INSTANT_APP_EXTRAS
A {@link Bundle} of metadata that describes the instant application that needs to be installed. This data is populated from the response to {@link android.content.pm.InstantAppResolveInfo#getExtras()} as provided by the registered instant application resolver. @hide
Implementation
static const String EXTRA_INSTANT_APP_EXTRAS =
"android.intent.extra.INSTANT_APP_EXTRAS";