EXTRA_NOT_UNKNOWN_SOURCE constant
String
const EXTRA_NOT_UNKNOWN_SOURCE
Used as a boolean extra field with {@link #ACTION_INSTALL_PACKAGE} to install a package. Specifies that the application being installed should not be treated as coming from an unknown source, but as coming from the app invoking the Intent. For this to work you must start the installer with startActivityForResult().
Implementation
static const String EXTRA_NOT_UNKNOWN_SOURCE =
"android.intent.extra.NOT_UNKNOWN_SOURCE";