EXTRA_PHONE_NUMBER constant
String
const EXTRA_PHONE_NUMBER
A String holding the phone number originally entered in {@link android.content.Intent#ACTION_NEW_OUTGOING_CALL}, or the actual number to call in a {@link android.content.Intent#ACTION_CALL}.
Implementation
static const String EXTRA_PHONE_NUMBER = "android.intent.extra.PHONE_NUMBER";