EXTRA_QUIET_MODE constant
String
const EXTRA_QUIET_MODE
Optional boolean extra indicating whether quiet mode has been switched on or off. When a profile goes into quiet mode, all apps in the profile are killed and the profile user is stopped. Widgets originating from the profile are masked, and app launcher icons are grayed out.
Implementation
static const String EXTRA_QUIET_MODE = "android.intent.extra.QUIET_MODE";