EXTRA_REFERRER_NAME constant
String
const EXTRA_REFERRER_NAME
Alternate version of {@link #EXTRA_REFERRER} that supplies the URI as a String rather than a {@link android.net.Uri} object. Only for use in cases where Uri objects can not be created, in particular when Intent extras are supplied through the {@link #URI_INTENT_SCHEME intent:} or {@link #URI_ANDROID_APP_SCHEME android-app:} schemes.
@see #EXTRA_REFERRER
Implementation
static const String EXTRA_REFERRER_NAME =
"android.intent.extra.REFERRER_NAME";