EXTRA_REMOVED_FOR_ALL_USERS constant
String
const EXTRA_REMOVED_FOR_ALL_USERS
@hide Used as a boolean extra field in {@link android.content.Intent#ACTION_PACKAGE_REMOVED} intents to indicate that at this point the package has been removed for all users on the device.
Implementation
static const String EXTRA_REMOVED_FOR_ALL_USERS =
"android.intent.extra.REMOVED_FOR_ALL_USERS";