EXTRA_UNINSTALL_ALL_USERS constant
String
const EXTRA_UNINSTALL_ALL_USERS
Specify whether the package should be uninstalled for all users. @hide because these should not be part of normal application flow.
Implementation
static const String EXTRA_UNINSTALL_ALL_USERS =
"android.intent.extra.UNINSTALL_ALL_USERS";