EXTRA_WIPE_ESIMS constant
String
const EXTRA_WIPE_ESIMS
{@hide} This extra will be set to true when the user choose to wipe the data on eSIM during factory reset for the device with eSIM. This extra will be sent together with {@link #ACTION_FACTORY_RESET}
Implementation
static const String EXTRA_WIPE_ESIMS =
"com.android.internal.intent.extra.WIPE_ESIMS";