FLAG_ACTIVITY_CLEAR_TASK constant
int
const FLAG_ACTIVITY_CLEAR_TASK
If set in an Intent passed to {@link Context#startActivity Context.startActivity()}, this flag will cause any existing task that would be associated with the activity to be cleared before the activity is started. That is, the activity becomes the new root of an otherwise empty task, and any old activities are finished. This can only be used in conjunction with {@link #FLAG_ACTIVITY_NEW_TASK}.
Implementation
static const int FLAG_ACTIVITY_CLEAR_TASK = 0X00008000;