FLAG_ACTIVITY_REORDER_TO_FRONT constant
int
const FLAG_ACTIVITY_REORDER_TO_FRONT
If set in an Intent passed to {@link Context#startActivity Context.startActivity()}, this flag will cause the launched activity to be brought to the front of its task's history stack if it is already running.
For example, consider a task consisting of four activities: A, B, C, D. If D calls startActivity() with an Intent that resolves to the component of activity B, then B will be brought to the front of the history stack, with this resulting order: A, C, D, B.
This flag will be ignored if {@link #FLAG_ACTIVITY_CLEAR_TOP} is also specified.
Implementation
static const int FLAG_ACTIVITY_REORDER_TO_FRONT = 0X00020000;