FLAG_ACTIVITY_SINGLE_TOP constant
int
const FLAG_ACTIVITY_SINGLE_TOP
If set, the activity will not be launched if it is already running at the top of the history stack.
Implementation
static const int FLAG_ACTIVITY_SINGLE_TOP = 0x20000000;