FLAG_DIRECT_BOOT_AUTO constant
int
const FLAG_DIRECT_BOOT_AUTO
Flag used to automatically match intents based on their Direct Boot awareness and the current user state.
Since the default behavior is to automatically apply the current user state, this is effectively a sentinel value that doesn't change the output of any queries based on its presence or absence.
Instead, this value can be useful in conjunction with {@link android.os.StrictMode.VmPolicy.Builder#detectImplicitDirectBoot()} to detect when a caller is relying on implicit automatic matching, instead of confirming the explicit behavior they want.
Implementation
static const int FLAG_DIRECT_BOOT_AUTO = 0x00000100;