FLAG_INCLUDE_STOPPED_PACKAGES constant
int
const FLAG_INCLUDE_STOPPED_PACKAGES
If set, this intent will always match any components in packages that are currently stopped. This is the default behavior when {@link #FLAG_EXCLUDE_STOPPED_PACKAGES} is not set. If both of these flags are set, this one wins (it allows overriding of exclude for places where the framework may automatically set the exclude flag).
Implementation
static const int FLAG_INCLUDE_STOPPED_PACKAGES = 0x00000020;