FLAG_RECEIVER_BOOT_UPGRADE constant
int
const FLAG_RECEIVER_BOOT_UPGRADE
Set when this broadcast is for a boot upgrade, a special mode that allows the broadcast to be sent before the system is ready and launches the app process with no providers running in it. @hide
Implementation
static const int FLAG_RECEIVER_BOOT_UPGRADE = 0x02000000;