FLAG_RECEIVER_EXCLUDE_BACKGROUND constant
int
const FLAG_RECEIVER_EXCLUDE_BACKGROUND
If set, the broadcast will never go to manifest receivers in background (cached or not running) apps, regardless of whether that would be done by default. By default they will receive broadcasts if the broadcast has specified an explicit component or package name. @hide
Implementation
static const int FLAG_RECEIVER_EXCLUDE_BACKGROUND = 0x00800000;