FLAG_RECEIVER_FOREGROUND constant
int
const FLAG_RECEIVER_FOREGROUND
If set, when sending a broadcast the recipient is allowed to run at foreground priority, with a shorter timeout interval. During normal broadcasts the receivers are not automatically hoisted out of the background priority class.
Implementation
static const int FLAG_RECEIVER_FOREGROUND = 0x10000000;