PackageItemInfo class
- Implementers
Constructors
Properties
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon ↔ int
-
getter/setter pair
- labelRes ↔ int
-
getter/setter pair
- logo ↔ int
-
getter/setter pair
- name ↔ String?
-
getter/setter pair
- nonLocalizedLabel ↔ String?
-
getter/setter pair
- packageName ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getApplicationInfo(
) → ApplicationInfo? -
loadBanner(
PackageManager pm) → Uint8List? -
loadIcon(
PackageManager pm) → Uint8List -
loadLabel(
PackageManager pm) → String -
loadLogo(
PackageManager pm) → Uint8List? -
loadUnbadgedIcon(
PackageManager pm) → Uint8List -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
forceSafeLabels(
) → void
Constants
- DEFAULT_MAX_LABEL_SIZE_PX → const double
- MAX_SAFE_LABEL_LENGTH → const int
- SAFE_LABEL_FLAG_FIRST_LINE → const int
- SAFE_LABEL_FLAG_SINGLE_LINE → const int
- SAFE_LABEL_FLAG_TRIM → const int