RINGER_MODE_NORMAL constant
int
const RINGER_MODE_NORMAL
Ringer mode that may be audible and may vibrate. It will be audible if the volume before changing out of this mode was audible. It will vibrate if the vibrate setting is on.
@see #setRingerMode(int) @see #getRingerMode()
Implementation
static const int RINGER_MODE_NORMAL = 2;