VIBRATE_SETTING_ON constant
int
const VIBRATE_SETTING_ON
Vibrate setting that suggests to vibrate when possible.
@see #setVibrateSetting(int, int) @see #getVibrateSetting(int) @deprecated Applications should maintain their own vibrate policy based on current ringer mode that can be queried via {@link #getRingerMode()}.
Implementation
static const int VIBRATE_SETTING_ON = 1;