adjustVolume method
Adjusts the volume of the most relevant stream. For example, if a call is active, it will have the highest priority regardless of if the in-call screen is showing. Another example, if music is playing in the background and a call is not active, the music stream will be adjusted.
This method should only be used by applications that replace the platform-wide management of audio settings or the main telephony application.
@param direction The direction to adjust the volume. One of {@link #ADJUST_LOWER}, {@link #ADJUST_RAISE}, or {@link #ADJUST_SAME}. @param flags One or more flags. @see #adjustSuggestedStreamVolume(int, int, int) @see #adjustStreamVolume(int, int, int) @see #setStreamVolume(int, int, int)
Implementation
Future adjustVolume(int direction, int flags) async {}