setStreamSolo method
Solo or unsolo a particular stream. All other streams are muted.
The solo command is protected against client process death: if a process with an active solo request on a stream dies, all streams that were muted because of this request will be unmuted automatically.
The solo requests for a given stream are cumulative: the AudioManager can receive several solo requests from one or more clients and the stream will be unsoloed only when the same number of unsolo requests are received.
For a better user experience, applications MUST unsolo a soloed stream in onPause() and solo is again in onResume() if appropriate.
@param streamType The stream to be soloed/unsoloed. @param state The required solo state: true for solo ON, false for solo OFF
Implementation
Future setStreamSolo(int streamType, bool state) async {}