getIntegerArrayList method
Returns the value associated with the given key, or null if no mapping of the desired type exists for the given key or a null value is explicitly associated with the key.
@param key a String, or null @return an ArrayList
Implementation
List<int>? getIntegerArrayList(String key) {
return getIntList(key);
}