putBoolean method
Inserts a Boolean value into the mapping of this Bundle, replacing any existing value for the given key. Either key or value may be null.
@param key a String, or null @param value a boolean
Implementation
void putBoolean(String key, bool value) {
// unparcel();
_map[key] = value;
}