ACTION_NETWORK_OPERATOR_SETTINGS constant
String
const ACTION_NETWORK_OPERATOR_SETTINGS
Activity Action: Show settings for selecting the network operator.
In some cases, a matching Activity may not exist, so ensure you safeguard against this.
The subscription ID of the subscription for which available network operators should be displayed may be optionally specified with {@link #EXTRA_SUB_ID}.
Input: Nothing.
Output: Nothing.
Implementation
static const String ACTION_NETWORK_OPERATOR_SETTINGS =
"android.settings.NETWORK_OPERATOR_SETTINGS";