ACTION_TRUSTED_CREDENTIALS_USER constant
String
const ACTION_TRUSTED_CREDENTIALS_USER
Activity Action: Show trusted credentials settings, opening to the user tab, to allow management of installed credentials.
In some cases, a matching Activity may not exist, so ensure you safeguard against this.
Input: Nothing.
Output: Nothing. @hide
Implementation
static const String ACTION_TRUSTED_CREDENTIALS_USER =
"com.android.settings.TRUSTED_CREDENTIALS_USER";